
<!--
FrozenIsBool False
-->

#Getter

##Doc
----


> 
> A Getter helps for getting attributes safely in 
> an instance. Through the __getitem__ method, It looks first in the \_\_dict\_\_ to 
> check if there is the corresponding GettingKeyStr.
> 
> 

----

<small>
View the Getter notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Getter.ipynb)
</small>

